@@ -8,9 +8,6 @@ use crate::{
 use byteorder::{ByteOrder, NativeEndian};
 use libc::c_uint;
 use mem::size_of;
-#[cfg(windows)]
-use std::ffi::OsStr;
-#[cfg(unix)]
 use std::os::unix::ffi::OsStrExt;
 use std::{
     ffi::CString,
@@ -26,18 +23,6 @@ use std::{
     time::Duration,
 };
 
-#[cfg(windows)]
-/// Adding a 'missing' trait from windows OsStrExt
-trait OsStrExtLmdb {
-    fn as_bytes(&self) -> &[u8];
-}
-#[cfg(windows)]
-impl OsStrExtLmdb for OsStr {
-    fn as_bytes(&self) -> &[u8] {
-        self.to_str().unwrap().as_bytes()
-    }
-}
-
 mod private {
     use super::*;
 
@@ -425,20 +410,14 @@ where
 {
     /// Open an environment.
     ///
-    /// On UNIX, the database files will be opened with 644 permissions.
-    ///
-    /// The path may not contain the null character, Windows UNC (Uniform Naming Convention)
-    /// paths are not supported either.
+    /// Database files will be opened with 644 permissions.
     pub fn open(&self, path: &Path) -> Result<Environment<E>> {
         self.open_with_permissions(path, 0o644)
     }
 
     /// Open an environment with the provided UNIX permissions.
     ///
-    /// On Windows, the permissions will be ignored.
-    ///
-    /// The path may not contain the null character, Windows UNC (Uniform Naming Convention)
-    /// paths are not supported either.
+    /// The path may not contain the null character.
     pub fn open_with_permissions(
         &self,
         path: &Path,
